@@ -1,5 +1,5 @@
 """Default execution entry point if running the package via python -m."""
-import asyncio
+
 import sys
 
 from . import cli
@@ -7,7 +7,7 @@ from . import cli
 
 def main():
     """Run cli from script entry point."""
-    asyncio.run(cli.main())
+    cli.main()
 
 
 if __name__ == "__main__":
